=====================
``codec.base`` module
=====================

.. automodule:: whoosh.codec.base


Classes
=======

.. autoclass:: Codec
   :members:

.. autoclass:: PerDocumentWriter
   :members:

.. autoclass:: FieldWriter
   :members:

.. autoclass:: PostingsWriter
   :members:

.. autoclass:: TermsReader
   :members:

.. autoclass:: PerDocumentReader
   :members:

.. autoclass:: Segment
   :members:


